---
title: <span class="badge object-type-scalar"></span> Candela
---
# <span class="badge object-type-scalar"></span> Candela

Candela (cd)

## Definition

```python
# Candela (cd)
Candela: typing.Literal["candela"] = "candela"
```
